==> openshift-model-5.9.0-sources.jar: io/fabric8/openshift/api/model/SourceControlUserBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class SourceControlUserBuilder extends io.fabric8.openshift.api.model.SourceControlUserFluentImpl<io.fabric8.openshift.api.model.SourceControlUserBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.SourceControlUser,io.fabric8.openshift.api.model.SourceControlUserBuilder>{
  public SourceControlUserBuilder() {
    this(false);
  }
  public SourceControlUserBuilder(java.lang.Boolean validationEnabled) {
    this(new SourceControlUser(), validationEnabled);
  }
  public SourceControlUserBuilder(io.fabric8.openshift.api.model.SourceControlUserFluent<?> fluent) {
    this(fluent, false);
  }
  public SourceControlUserBuilder(io.fabric8.openshift.api.model.SourceControlUserFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new SourceControlUser(), validationEnabled);
  }
  public SourceControlUserBuilder(io.fabric8.openshift.api.model.SourceControlUserFluent<?> fluent,io.fabric8.openshift.api.model.SourceControlUser instance) {
    this(fluent, instance, false);
  }
  public SourceControlUserBuilder(io.fabric8.openshift.api.model.SourceControlUserFluent<?> fluent,io.fabric8.openshift.api.model.SourceControlUser instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withEmail(instance.getEmail()); 
    fluent.withName(instance.getName()); 
    this.validationEnabled = validationEnabled; 
  }
  public SourceControlUserBuilder(io.fabric8.openshift.api.model.SourceControlUser instance) {
    this(instance,false);
  }
  public SourceControlUserBuilder(io.fabric8.openshift.api.model.SourceControlUser instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withEmail(instance.getEmail()); 
    this.withName(instance.getName()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.SourceControlUserFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.SourceControlUser build() {
    SourceControlUser buildable = new SourceControlUser(fluent.getEmail(),fluent.getName());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SourceControlUserBuilder that = (SourceControlUserBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.12.1-sources.jar: io/fabric8/openshift/api/model/SourceControlUserBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class SourceControlUserBuilder extends io.fabric8.openshift.api.model.SourceControlUserFluentImpl<io.fabric8.openshift.api.model.SourceControlUserBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.SourceControlUser,io.fabric8.openshift.api.model.SourceControlUserBuilder>{
  public SourceControlUserBuilder() {
    this(false);
  }
  public SourceControlUserBuilder(java.lang.Boolean validationEnabled) {
    this(new SourceControlUser(), validationEnabled);
  }
  public SourceControlUserBuilder(io.fabric8.openshift.api.model.SourceControlUserFluent<?> fluent) {
    this(fluent, false);
  }
  public SourceControlUserBuilder(io.fabric8.openshift.api.model.SourceControlUserFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new SourceControlUser(), validationEnabled);
  }
  public SourceControlUserBuilder(io.fabric8.openshift.api.model.SourceControlUserFluent<?> fluent,io.fabric8.openshift.api.model.SourceControlUser instance) {
    this(fluent, instance, false);
  }
  public SourceControlUserBuilder(io.fabric8.openshift.api.model.SourceControlUserFluent<?> fluent,io.fabric8.openshift.api.model.SourceControlUser instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withEmail(instance.getEmail()); 
    fluent.withName(instance.getName()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public SourceControlUserBuilder(io.fabric8.openshift.api.model.SourceControlUser instance) {
    this(instance,false);
  }
  public SourceControlUserBuilder(io.fabric8.openshift.api.model.SourceControlUser instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withEmail(instance.getEmail()); 
    this.withName(instance.getName()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.SourceControlUserFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.SourceControlUser build() {
    SourceControlUser buildable = new SourceControlUser(fluent.getEmail(),fluent.getName());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SourceControlUserBuilder that = (SourceControlUserBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
